==> phoenix_widgets-1.16.5.tar.gz: example/lib/phoenix_bottom_sheet_tile_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixBottomSheetTilePage extends StatefulWidget {
  const PhoenixBottomSheetTilePage({Key? key}) : super(key: key);

  @override
  _PhoenixBottomSheetTilePageState createState() =>
      _PhoenixBottomSheetTilePageState();
}

class _PhoenixBottomSheetTilePageState
    extends State<PhoenixBottomSheetTilePage> {
  final PhoenixBottomSheetTile _bottomSheetHowItWorks =
      PhoenixBottomSheetTile();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text('Phoenix Bottom Sheet Tile Sample'),
        ),
        body: Center(
            child: ElevatedButton(
          child: const Text("Show All Products"),
          onPressed: () {
            _bottomSheetHowItWorks(
              context,
              spacing: const EdgeInsets.only(bottom: 16.0),
              padding: const EdgeInsets.only(
                top: 16,
                bottom: 58,
              ),
              title: 'Title of bottom sheet',
              style: const TextStyle(
                color: Color(0xFF212124),
                fontSize: 16,
                fontWeight: FontWeight.w500,
              ),
              child: CustomScrollView(
                shrinkWrap: true,
                slivers: [
                  PhoenixProductTiles(
                    onTap: (index) {},
                    items: _items,
                  )
                ],
              ),
            );
          },
        )));
  }
}

final List<PhoenixProductItem> _items = [
  PhoenixProductItem(
      "Tile 1",
      SvgPicture.asset(
        "assets/education.svg",
        width: 46,
        height: 46,
      )),
  PhoenixProductItem(
      "Tile 2",
      SvgPicture.asset(
        "assets/education.svg",
        width: 46,
        height: 46,
      )),
  PhoenixProductItem(
      "Tile 3",
      SvgPicture.asset(
        "assets/education.svg",
        width: 46,
        height: 46,
      ),
      label: "Coming Soon"),
  PhoenixProductItem(
      "Tile 4",
      SvgPicture.asset(
        "assets/education.svg",
        width: 46,
        height: 46,
      ),
      label: "Coming Soon"),
  PhoenixProductItem(
      "Tile 5",
      Image.asset(
        "assets/tab_home.png",
        width: 45,
        height: 45,
      )),
  PhoenixProductItem(
      "Tile 6",
      Image.asset(
        "assets/tab_home.png",
        width: 45,
        height: 45,
      )),
  PhoenixProductItem(
      "Tile 7",
      Image.asset(
        "assets/tab_home.png",
        width: 45,
        height: 45,
      ),
      label: "Coming Soon"),
  PhoenixProductItem(
      "Tile 8",
      Image.asset(
        "assets/tab_home.png",
        width: 45,
        height: 45,
      ),
      label: "Coming Soon"),
];

==> phoenix_widgets-1.17.4.tar.gz: example/lib/phoenix_bottom_sheet_tile_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:phoenix_widgets/phoenix_widgets.dart';

class PhoenixBottomSheetTilePage extends StatefulWidget {
  const PhoenixBottomSheetTilePage({Key? key}) : super(key: key);

  @override
  State<PhoenixBottomSheetTilePage> createState() =>
      _PhoenixBottomSheetTilePageState();
}

class _PhoenixBottomSheetTilePageState
    extends State<PhoenixBottomSheetTilePage> {
  final PhoenixBottomSheetTile _bottomSheetHowItWorks =
      PhoenixBottomSheetTile();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        appBar: AppBar(
          title: const Text('Phoenix Bottom Sheet Tile Sample'),
        ),
        body: Center(
            child: ElevatedButton(
          child: const Text("Show All Products"),
          onPressed: () {
            _bottomSheetHowItWorks(
              context,
              spacing: const EdgeInsets.only(bottom: 16.0),
              padding: const EdgeInsets.only(
                top: 16,
                bottom: 58,
              ),
              title: 'Title of bottom sheet',
              style: const TextStyle(
                color: Color(0xFF212124),
                fontSize: 16,
                fontWeight: FontWeight.w500,
              ),
              child: CustomScrollView(
                shrinkWrap: true,
                slivers: [
                  PhoenixProductTiles(
                    onTap: (index) {},
                    items: _items,
                  )
                ],
              ),
            );
          },
        )));
  }
}

final List<PhoenixProductItem> _items = [
  PhoenixProductItem(
      "Tile 1",
      SvgPicture.asset(
        "assets/education.svg",
        width: 46,
        height: 46,
      )),
  PhoenixProductItem(
      "Tile 2",
      SvgPicture.asset(
        "assets/education.svg",
        width: 46,
        height: 46,
      )),
  PhoenixProductItem(
      "Tile 3",
      SvgPicture.asset(
        "assets/education.svg",
        width: 46,
        height: 46,
      ),
      label: "Coming Soon"),
  PhoenixProductItem(
      "Tile 4",
      SvgPicture.asset(
        "assets/education.svg",
        width: 46,
        height: 46,
      ),
      label: "Coming Soon"),
  PhoenixProductItem(
      "Tile 5",
      Image.asset(
        "assets/tab_home.png",
        width: 45,
        height: 45,
      )),
  PhoenixProductItem(
      "Tile 6",
      Image.asset(
        "assets/tab_home.png",
        width: 45,
        height: 45,
      )),
  PhoenixProductItem(
      "Tile 7",
      Image.asset(
        "assets/tab_home.png",
        width: 45,
        height: 45,
      ),
      label: "Coming Soon"),
  PhoenixProductItem(
      "Tile 8",
      Image.asset(
        "assets/tab_home.png",
        width: 45,
        height: 45,
      ),
      label: "Coming Soon"),
];
